pub struct TableDirectory<'a> { /* private fields */ }Expand description
The OpenType Table Directory
Implementations
Sourceimpl<'a> TableDirectory<'a>
impl<'a> TableDirectory<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn sfnt_version(&self) -> u32
pub fn sfnt_version(&self) -> u32
0x00010000 or 0x4F54544F
Sourcepub fn num_tables(&self) -> u16
pub fn num_tables(&self) -> u16
Number of tables.
pub fn search_range(&self) -> u16
pub fn entry_selector(&self) -> u16
pub fn range_shift(&self) -> u16
Sourcepub fn table_records(&self) -> &'a [TableRecord]
pub fn table_records(&self) -> &'a [TableRecord]
Table records array—one for each top-level table in the font
pub fn sfnt_version_byte_range(&self) -> Range<usize> ⓘ
pub fn num_tables_byte_range(&self) -> Range<usize> ⓘ
pub fn search_range_byte_range(&self) -> Range<usize> ⓘ
pub fn entry_selector_byte_range(&self) -> Range<usize> ⓘ
pub fn range_shift_byte_range(&self) -> Range<usize> ⓘ
pub fn table_records_byte_range(&self) -> Range<usize> ⓘ