BaseScriptList

Struct BaseScriptList 

pub struct BaseScriptList<'a> { /* private fields */ }
Implementations

Source

impl<'a> BaseScriptList<'a>

pub const MIN_SIZE: usize = u16::RAW_BYTE_LEN

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated:

just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn base_script_count(&self) -> u16

Number of BaseScriptRecords defined

pub fn base_script_records(&self) -> &'a [BaseScriptRecord]

Array of BaseScriptRecords, in alphabetical order by baseScriptTag

pub fn base_script_count_byte_range(&self) -> Range<usize>

pub fn base_script_records_byte_range(&self) -> Range<usize>