pub struct BaseValues<'a> { /* private fields */ }Expand description
BaseValues table
Implementations
Sourceimpl<'a> BaseValues<'a>
impl<'a> BaseValues<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn default_baseline_index(&self) -> u16
pub fn default_baseline_index(&self) -> u16
Index number of default baseline for this script — equals index position of baseline tag in baselineTags array of the BaseTagList
Sourcepub fn base_coord_count(&self) -> u16
pub fn base_coord_count(&self) -> u16
Number of BaseCoord tables defined — should equal baseTagCount in the BaseTagList
Sourcepub fn base_coord_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn base_coord_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to BaseCoord tables, from beginning of BaseValues table — order matches baselineTags array in the BaseTagList
Sourcepub fn base_coords(&self) -> ArrayOfOffsets<'a, BaseCoord<'a>, Offset16>
pub fn base_coords(&self) -> ArrayOfOffsets<'a, BaseCoord<'a>, Offset16>
A dynamically resolving wrapper for base_coord_offsets.
pub fn default_baseline_index_byte_range(&self) -> Range<usize> ⓘ
pub fn base_coord_count_byte_range(&self) -> Range<usize> ⓘ
pub fn base_coord_offsets_byte_range(&self) -> Range<usize> ⓘ