pub struct MinMax<'a> { /* private fields */ }Expand description
MinMax table
Implementations
Sourceimpl<'a> MinMax<'a>
impl<'a> MinMax<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn min_coord_offset(&self) -> Nullable<Offset16>
pub fn min_coord_offset(&self) -> Nullable<Offset16>
Offset to BaseCoord table that defines the minimum extent value, from the beginning of MinMax table (may be NULL)
Sourcepub fn min_coord(&self) -> Option<Result<BaseCoord<'a>, ReadError>>
pub fn min_coord(&self) -> Option<Result<BaseCoord<'a>, ReadError>>
Attempt to resolve min_coord_offset.
Sourcepub fn max_coord_offset(&self) -> Nullable<Offset16>
pub fn max_coord_offset(&self) -> Nullable<Offset16>
Offset to BaseCoord table that defines maximum extent value, from the beginning of MinMax table (may be NULL)
Sourcepub fn max_coord(&self) -> Option<Result<BaseCoord<'a>, ReadError>>
pub fn max_coord(&self) -> Option<Result<BaseCoord<'a>, ReadError>>
Attempt to resolve max_coord_offset.
Sourcepub fn feat_min_max_count(&self) -> u16
pub fn feat_min_max_count(&self) -> u16
Number of FeatMinMaxRecords — may be zero (0)
Sourcepub fn feat_min_max_records(&self) -> &'a [FeatMinMaxRecord]
pub fn feat_min_max_records(&self) -> &'a [FeatMinMaxRecord]
Array of FeatMinMaxRecords, in alphabetical order by featureTableTag