pub struct Cmap8<'a> { /* private fields */ }Expand description
cmap Format 8: mixed 16-bit and 32-bit coverage
Implementations
Sourceimpl<'a> Cmap8<'a>
impl<'a> Cmap8<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn language(&self) -> u32
pub fn language(&self) -> u32
For requirements on use of the language field, see “Use of the language field in ‘cmap’ subtables” in this document.
Sourcepub fn is32(&self) -> &'a [u8] ⓘ
pub fn is32(&self) -> &'a [u8] ⓘ
Tightly packed array of bits (8K bytes total) indicating whether the particular 16-bit (index) value is the start of a 32-bit character code
Sourcepub fn num_groups(&self) -> u32
pub fn num_groups(&self) -> u32
Number of groupings which follow
Sourcepub fn groups(&self) -> &'a [SequentialMapGroup]
pub fn groups(&self) -> &'a [SequentialMapGroup]
Array of SequentialMapGroup records.