ClassDef

Enum ClassDef 

pub enum ClassDef<'a> {
    Format1(ClassDefFormat1<'a>),
    Format2(ClassDefFormat2<'a>),
}
Variants



Format1(ClassDefFormat1<'a>)



Format2(ClassDefFormat2<'a>)

Implementations

Source

impl<'a> ClassDef<'a>

pub fn offset_data(&self) -> FontData<'a>

Return the FontData used to resolve offsets for this table.

pub fn class_format(&self) -> u16

Format identifier — format = 1

Source

impl ClassDef<'_>

pub fn get(&self, gid: impl Into<GlyphId>) -> u16

Get the class for this glyph id

pub fn iter(&self) -> impl Iterator<Item = (GlyphId16, u16)> + '_

Iterate over each glyph and its class.

This will not include class 0 unless it has been explicitly assigned.

pub fn population(&self) -> usize

Return the number of glyphs explicitly assigned to a class in this table

pub fn cost(&self) -> u32

Return the cost of looking up a glyph in this table

pub fn intersect_classes(&self, glyphs: &IntSet<GlyphId>) -> IntSet<u16>

Available on crate feature std only.

Returns class values for the intersected glyphs of this table and input ‘glyphs’ set.

pub fn intersected_class_glyphs( &self, glyphs: &IntSet<GlyphId>, class: u16, ) -> IntSet<GlyphId>

Available on crate feature std only.

Returns intersected glyphs of this table and input ‘glyphs’ set that are assgiend to input class value.

pub fn intersects_class_glyphs( &self, glyphs: &IntSet<GlyphId>, class: u16, ) -> bool

Available on crate feature std only.

Checks whether any glyph in the given glyphs set intersects with this table and is assigned to the specified class value.