pub struct Script<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> Script<'a>
impl<'a> Script<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn default_lang_sys_offset(&self) -> Nullable<Offset16>
pub fn default_lang_sys_offset(&self) -> Nullable<Offset16>
Offset to default LangSys table, from beginning of Script table — may be NULL
Sourcepub fn default_lang_sys(&self) -> Option<Result<LangSys<'a>, ReadError>>
pub fn default_lang_sys(&self) -> Option<Result<LangSys<'a>, ReadError>>
Attempt to resolve default_lang_sys_offset.
Sourcepub fn lang_sys_count(&self) -> u16
pub fn lang_sys_count(&self) -> u16
Number of LangSysRecords for this script — excluding the default LangSys
Sourcepub fn lang_sys_records(&self) -> &'a [LangSysRecord]
pub fn lang_sys_records(&self) -> &'a [LangSysRecord]
Array of LangSysRecords, listed alphabetically by LangSys tag
pub fn default_lang_sys_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn lang_sys_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lang_sys_records_byte_range(&self) -> Range<usize> ⓘ