DataMapRecord

Struct DataMapRecord 

#[repr(C, packed(1))]
pub struct DataMapRecord { pub tag: BigEndian<Tag>, pub data_offset: BigEndian<Offset32>, pub data_length: BigEndian<u32>, }
Fields

tag: BigEndian<Tag>

A tag indicating the type of metadata.

data_offset: BigEndian<Offset32>

Offset in bytes from the beginning of the metadata table to the data for this tag.

data_length: BigEndian<u32>

Length of the data, in bytes. The data is not required to be padded to any byte boundary.

Implementations

Source

impl DataMapRecord

pub fn tag(&self) -> Tag

A tag indicating the type of metadata.

pub fn data_offset(&self) -> Offset32

Offset in bytes from the beginning of the metadata table to the data for this tag.

pub fn data<'a>(&self, data: FontData<'a>) -> Result<Metadata<'a>, ReadError>

Offset in bytes from the beginning of the metadata table to the data for this tag.

The data argument should be retrieved from the parent table By calling its offset_data method.

pub fn data_length(&self) -> u32

Length of the data, in bytes. The data is not required to be padded to any byte boundary.