pub struct AxisValueArray<'a> { /* private fields */ }Expand description
An array of AxisValue tables.
Implementations
Sourceimpl<'a> AxisValueArray<'a>
impl<'a> AxisValueArray<'a>
Sourceimpl<'a> AxisValueArray<'a>
impl<'a> AxisValueArray<'a>
pub const MIN_SIZE: usize = 0
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn axis_value_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn axis_value_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to axis value tables, in bytes from the start of the axis value offsets array.
Sourcepub fn axis_values(&self) -> ArrayOfOffsets<'a, AxisValue<'a>, Offset16>
pub fn axis_values(&self) -> ArrayOfOffsets<'a, AxisValue<'a>, Offset16>
A dynamically resolving wrapper for axis_value_offsets.
pub fn axis_value_offsets_byte_range(&self) -> Range<usize> ⓘ