TupleVariationHeader

Struct TupleVariationHeader 

pub struct TupleVariationHeader<'a> { /* private fields */ }
Implementations

Source

impl<'a> TupleVariationHeader<'a>

pub fn read(data: FontData<'a>, axis_count: u16) -> Result<Self, ReadError>

A constructor that requires additional arguments.

This type requires some external state in order to be parsed.

Source

impl<'a> TupleVariationHeader<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated:

just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn variation_data_size(&self) -> u16

The size in bytes of the serialized data for this tuple variation table.

pub fn tuple_index(&self) -> TupleIndex

A packed field. The high 4 bits are flags (see below). The low 12 bits are an index into a shared tuple records array.

pub fn variation_data_size_byte_range(&self) -> Range<usize>

pub fn tuple_index_byte_range(&self) -> Range<usize>

pub fn peak_tuple_byte_range(&self) -> Range<usize>

pub fn intermediate_start_tuple_byte_range(&self) -> Range<usize>

pub fn intermediate_end_tuple_byte_range(&self) -> Range<usize>

Source

impl<'a> TupleVariationHeader<'a>

pub fn peak_tuple(&self) -> Option<Tuple<'a>>

Peak tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value. Note that this must always be included in the ‘cvar’ table.

pub fn intermediate_start_tuple(&self) -> Option<Tuple<'a>>

Intermediate start tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value.

pub fn intermediate_end_tuple(&self) -> Option<Tuple<'a>>

Intermediate end tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value.

pub fn intermediate_tuples(&self) -> Option<(Tuple<'a>, Tuple<'a>)>

Intermediate tuple records for this tuple variation table — optional, determined by flags in the tupleIndex value.