pub struct TupleVariationHeader<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> TupleVariationHeader<'a>
impl<'a> TupleVariationHeader<'a>
Sourceimpl<'a> TupleVariationHeader<'a>
impl<'a> TupleVariationHeader<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn variation_data_size(&self) -> u16
pub fn variation_data_size(&self) -> u16
The size in bytes of the serialized data for this tuple variation table.
Sourcepub fn tuple_index(&self) -> TupleIndex
pub fn tuple_index(&self) -> TupleIndex
A packed field. The high 4 bits are flags (see below). The low 12 bits are an index into a shared tuple records array.
pub fn variation_data_size_byte_range(&self) -> Range<usize> ⓘ
pub fn tuple_index_byte_range(&self) -> Range<usize> ⓘ
pub fn peak_tuple_byte_range(&self) -> Range<usize> ⓘ
pub fn intermediate_start_tuple_byte_range(&self) -> Range<usize> ⓘ
pub fn intermediate_end_tuple_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl<'a> TupleVariationHeader<'a>
impl<'a> TupleVariationHeader<'a>
Sourcepub fn peak_tuple(&self) -> Option<Tuple<'a>>
pub fn peak_tuple(&self) -> Option<Tuple<'a>>
Peak tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value. Note that this must always be included in the ‘cvar’ table.
Sourcepub fn intermediate_start_tuple(&self) -> Option<Tuple<'a>>
pub fn intermediate_start_tuple(&self) -> Option<Tuple<'a>>
Intermediate start tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value.
Sourcepub fn intermediate_end_tuple(&self) -> Option<Tuple<'a>>
pub fn intermediate_end_tuple(&self) -> Option<Tuple<'a>>
Intermediate end tuple record for this tuple variation table — optional, determined by flags in the tupleIndex value.
Sourcepub fn intermediate_tuples(&self) -> Option<(Tuple<'a>, Tuple<'a>)>
pub fn intermediate_tuples(&self) -> Option<(Tuple<'a>, Tuple<'a>)>
Intermediate tuple records for this tuple variation table — optional, determined by flags in the tupleIndex value.